﻿//********************************************************************************
//**
//**  Titel           : 
//**  Name            : WadExport.vb
//**  Typ             : DLL
//**  Copyright       : (c)2016 Christian Meyer
//**
//**  Beschreibung    : WinAlldatNet KIS Export DLL
//**
//**  Autor           : Christian Meyer
//**  Datum           : 17.12.2016
//**  Letzte Revision : 02.01.2017
//**  Status          : Konvertierung von WadExport.vb
//**
//********************************************************************************
using System;
using System.Diagnostics;

public class WadExport
{


    //********************************************************************************
    //*
    //********************************************************************************

    public struct ExportData
    {
        public int ipatid;
        public string adminid;
        public string patname;
        public string patfirstname;
        public string birthname;
        public string birthdate;
        public string sex;
        public string street;
        public string zipcode;
        public string city;
        public string country;
        public string phone_work;
        public string phone_athome;
        public string datecurrent;
        public string dateconsultation;
        public string documentname;
        //Dateipfad ohne Dateinamen
        public string documentpath;
        //Dateipfad mit Dateinamen
        public string documentfullpath;
        //TXT, PDF, XML, HTML
        public string documentformat;
        //TestProtocol, FindingsProtocol
        public string documenttype;
    }

    //********************************************************************************
    //*
    //********************************************************************************

    private ExportData oData;
    public ExportData Data
    {
        get { return oData; }
        set { oData = value; }
    }

    //********************************************************************************
    //*
    //********************************************************************************

    public bool Send(ExportData oData)
    {
        try
        {
            string sText = "";

            sText += "[Zusatz]" + Environment.NewLine;
            sText += "Quelle=DK_IVDK" + Environment.NewLine;
            sText += "Gruppe=" + Environment.NewLine;
            sText += "[Patient]" + Environment.NewLine;
            sText += "Patienten_ID=" + oData.adminid + Environment.NewLine;
            sText += "Titel=" + Environment.NewLine;
            sText += "Name=" + oData.patname + Environment.NewLine;
            sText += "Geburtsname=" + oData.birthname + Environment.NewLine;
            sText += "Vorname=" + oData.patfirstname + Environment.NewLine;
            sText += "Geschlecht=" + oData.sex + Environment.NewLine;
            sText += "Geburtsdatum=" + oData.birthdate + Environment.NewLine;
            sText += "SVNR_4=" + Environment.NewLine;
            sText += "[Fall]" + Environment.NewLine;
            sText += "KH_Kennzeichen=102" + Environment.NewLine;
            sText += "Aufnahmezahl=" + Environment.NewLine;
            sText += "SubPatNr=" + Environment.NewLine;
            sText += "Klinik=DK" + Environment.NewLine;
            sText += "DokLST=DKALLERG" + Environment.NewLine;
            sText += "Aufenthalt_von=" + Environment.NewLine;
            sText += "Aufenthalt_bis=" + Environment.NewLine;
            sText += "AmbKennzeichen=" + Environment.NewLine;
            sText += "[MEDOCS]" + Environment.NewLine;
            sText += "Fallnummer=" + Environment.NewLine;
            sText += "Fallart=" + Environment.NewLine;
            sText += "PID=" + oData.adminid + Environment.NewLine;
            sText += "Abgleich=" + Environment.NewLine;
            sText += "Archiv_Dok_ID=" + Environment.NewLine;
            sText += "[Dokument]" + Environment.NewLine;
            sText += "Dokumentart=KFB" + Environment.NewLine;
            sText += "Dokumentart_UG=ALERG" + Environment.NewLine;
            sText += "Beschreibung=" + Environment.NewLine;
            sText += "Dokumentdatum=" + oData.dateconsultation + Environment.NewLine;
            sText += "Dokument_ID=" + Environment.NewLine;
            sText += "Dateiformat=" + oData.documentformat + Environment.NewLine;
            sText += "Dateiname=" + oData.documentname + Environment.NewLine;
            sText += "Stylesheet=" + Environment.NewLine;

            //ToDo : Dateiname entsprach auch im alten WinAlldat IVDK nicht dem geforderten Dateinamen
            //       Irgendwo in der WinalldatGraz.dll eine unbekannte Dateinamen-Konvertierungen enthalten?

            //ToDo : Für die neue .xml-Ausgabe gibt es kein Stylesheet, .pdf- oder .html-ausgabe als Alternative?

            //ToDo : Berechnung des Zeitstempels ist unbekannt und wurde solange durch einen HHmm Zeitstempel ersetzt
            string sTime = DateTime.Now.ToShortTimeString().Replace(":", "");

            string sFileName = "Winalldat_" + oData.datecurrent + sTime + ".idx";
            WriteStringToFile(System.IO.Path.Combine(System.IO.Path.Combine(GetBaseDirectory(), "temp"), sFileName), sText);

            string sFileName2 = "Winalldat_" + oData.datecurrent + sTime + ".rdy";
            WriteStringToFile(System.IO.Path.Combine(System.IO.Path.Combine(GetBaseDirectory(), "temp"), sFileName2), sFileName);

            return true;
        }
        catch
        {
            return false;
        }
        return false;
        //Steht nur hier, damit der Kompiler nicht meckert
    }

    //********************************************************************************
    //*
    //********************************************************************************

    private string GetBaseDirectory()
    {
        try
        {
            return System.IO.Path.GetDirectoryName(Process.GetCurrentProcess().MainModule.FileName);
        }
        catch
        {
            return "";
        }
    }

    //********************************************************************************
    //*
    //********************************************************************************

    private bool WriteStringToFile(string sFileName, string sText)
    {
        System.IO.StreamWriter oStreamWriter = null;

        if (System.IO.File.Exists(sFileName) == true)
        {
            System.IO.File.Delete(sFileName);
        }

        oStreamWriter = new System.IO.StreamWriter(sFileName, true, System.Text.Encoding.Default);

        oStreamWriter.Write(sText);
        oStreamWriter.Flush();
        oStreamWriter.Close();
        return true;

    }

}


